Struct MockTestLayer

pub struct MockTestLayer<T: TestLayerTag> { /* private fields */ }
Available on crate feature _test only.

Implementations

Source

impl<T: TestLayerTag> MockTestLayer<T>

pub fn checkpoint(&mut self)

Validate that all current expectations for all methods have been satisfied, and discard them.

pub fn new() -> Self

Create a new mock object with no expectations.

This method will not be generated if the real struct already has a new method. However, it will be generated if the struct implements a trait with a new method. The trait’s new method can still be called like <MockX as TraitY>::new

Source

impl<T: TestLayerTag> MockTestLayer<T>

pub fn expect_manifest(&mut self) -> &mut Expectation<T>

Create an Expectation for mocking the manifest method

pub fn expect_hooked_global_commands(&mut self) -> &mut Expectation<T>

Create an Expectation for mocking the hooked_global_commands method

pub fn expect_hooked_instance_commands(&mut self) -> &mut Expectation<T>

Create an Expectation for mocking the hooked_instance_commands method

pub fn expect_hooked_device_commands(&mut self) -> &mut Expectation<T>

Create an Expectation for mocking the hooked_device_commands method

pub fn instance_context() -> Context<T>

Create a Context for mocking the instance method

pub fn mock_context() -> Context<T>

Create a Context for mocking the mock method

Source

impl<T: TestLayerTag> MockTestLayer<T>

pub fn set_default_expectations(&mut self)

Set the default behavior of the MockTestLayer: intercept no commands and a valid LayerManifest.