pub struct TestGlobalBuilder<T: TestLayerTag = Tag<0>> { /* private fields */ }Available on crate feature
_test only.Expand description
The builder for TestGlobal.
Implementations
Sourceimpl<T: TestLayerTag> TestGlobalBuilder<T>
impl<T: TestLayerTag> TestGlobalBuilder<T>
Sourcepub const fn set_layer_mock_builder(
self,
layer_mock_builder: fn() -> MockTestLayer<T>,
) -> Self
pub const fn set_layer_mock_builder( self, layer_mock_builder: fn() -> MockTestLayer<T>, ) -> Self
Specify how MockTestLayer should be created.
Can be used to customize the behavior of pre-initialized methods, like
InstanceInfo::hooked_commands.
Pre-initialized methods are almost always called, so it is usually needed to call
MockTestLayer::set_default_expectations right before return to provide a meaningful
default behavior.
Sourcepub const fn set_layer_global_builder(
self,
layer_global_builder: fn() -> Global<TestLayer<T>>,
) -> Self
pub const fn set_layer_global_builder( self, layer_global_builder: fn() -> Global<TestLayer<T>>, ) -> Self
Specify how Global<TestLayer<T>> should be created.
Can be used to customize the behavior and expectations of layer behaviors after Global
is initialized, especially the global commands, e.g.
GlobalHooks::create_instance.
Sourcepub const fn build(&self) -> TestGlobal<T>
pub const fn build(&self) -> TestGlobal<T>
Construct the TestGlobal<T>.
This is a const function, and can be directly used to initialize a static variable.